==> 0.0.1.tar.gz: lib/src/debounce_textfield.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

class DebounceTextfield extends StatefulWidget {
  Function action;
  VoidCallback? onTextfieldEmpty;
  Duration duration;
  double height;
  Widget leadingWidget;
  TextStyle textFieldStyle;
  BoxDecoration textFieldDecoration;
  InputDecoration inputDecoration;
  TextDirection direction;
  Widget clearButtonIcon;
  EdgeInsetsGeometry margin;
  EdgeInsetsGeometry padding;

  DebounceTextfield({
    required this.action,
    this.onTextfieldEmpty,
    this.duration = const Duration(milliseconds: 500),
    this.height = 40,
    this.leadingWidget = const SizedBox.shrink(),
    this.textFieldStyle = const TextStyle(fontSize: 13),
    this.textFieldDecoration = const BoxDecoration(color: Color(0xffE8E8E8)),
    this.inputDecoration = const InputDecoration.collapsed(
      hintText: 'Enter Your Text Here',
      hintStyle: TextStyle(fontSize: 13, color: Color(0xffaeaeae)),
    ),
    this.clearButtonIcon =
        const Icon(Icons.clear_rounded, color: Color(0xffaeaeae), size: 20),
    this.direction = TextDirection.ltr,
    this.margin = const EdgeInsets.fromLTRB(16, 8, 16, 8),
    this.padding = const EdgeInsets.fromLTRB(16, 8, 16, 8),
    Key? key,
  }) : super(key: key);

  @override
  State<DebounceTextfield> createState() => _DebounceTextfieldState();
}

class _DebounceTextfieldState extends State<DebounceTextfield> {
  late Function _action;
  late Duration _duration;
  late StreamController<bool> _btnClearController;
  late TextEditingController _inputController;
  Timer? _timer;

  @override
  void initState() {
    super.initState();
    _action = widget.action;
    _duration = widget.duration;
    _btnClearController = StreamController<bool>();
    _inputController = TextEditingController();
  }

  @override
  void dispose() {
    _btnClearController.close();
    _inputController.dispose();
    _timer?.cancel();
    super.dispose();
  }

  runDebouncer(String text) {
    _timer?.cancel();
    if (text.isNotEmpty) {
      _btnClearController.add(true);
      _timer = Timer(_duration, () => _action(text));
    } else {
      _btnClearController.add(false);
      if (widget.onTextfieldEmpty != null) {
        widget.onTextfieldEmpty!();
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: widget.direction,
      child: Container(
        height: widget.height,
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            widget.leadingWidget,
            const SizedBox(width: 5),
            Expanded(
              child: TextFormField(
                controller: _inputController,
                onChanged: (value) => runDebouncer(value),
                decoration: widget.inputDecoration,
                style: widget.textFieldStyle,
              ),
            ),
            StreamBuilder<bool>(
                stream: _btnClearController.stream,
                builder: (context, snapshot) {
                  return snapshot.data == true
                      ? GestureDetector(
                          onTap: () {
                            _inputController.clear();
                            _btnClearController.add(false);
                            if (widget.onTextfieldEmpty != null) {
                              widget.onTextfieldEmpty!();
                            }
                          },
                          child: widget.clearButtonIcon)
                      : const SizedBox.shrink();
                }),
          ],
        ),
        decoration: widget.textFieldDecoration,
        padding: widget.padding,
        margin: widget.margin,
      ),
    );
  }
}

==> 0.0.2.tar.gz: lib/src/debounce_textfield.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

class DebounceTextfield extends StatefulWidget {
  final Function action;
  final VoidCallback? onTextfieldEmpty;
  final Duration duration;
  final double height;
  final Widget leadingWidget;
  final TextStyle textFieldStyle;
  final BoxDecoration textFieldDecoration;
  final InputDecoration inputDecoration;
  final TextDirection direction;
  final Widget clearButtonIcon;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  const DebounceTextfield({
    required this.action,
    this.onTextfieldEmpty,
    this.duration = const Duration(milliseconds: 500),
    this.height = 40,
    this.leadingWidget = const SizedBox.shrink(),
    this.textFieldStyle = const TextStyle(fontSize: 13),
    this.textFieldDecoration = const BoxDecoration(color: Color(0xffE8E8E8)),
    this.inputDecoration = const InputDecoration.collapsed(
      hintText: 'Enter Your Text Here',
      hintStyle: TextStyle(fontSize: 13, color: Color(0xffaeaeae)),
    ),
    this.clearButtonIcon =
        const Icon(Icons.clear_rounded, color: Color(0xffaeaeae), size: 20),
    this.direction = TextDirection.ltr,
    this.margin = const EdgeInsets.fromLTRB(16, 8, 16, 8),
    this.padding = const EdgeInsets.fromLTRB(16, 8, 16, 8),
    Key? key,
  }) : super(key: key);

  @override
  State<DebounceTextfield> createState() => _DebounceTextfieldState();
}

class _DebounceTextfieldState extends State<DebounceTextfield> {
  late Function _action;
  late Duration _duration;
  late StreamController<bool> _btnClearController;
  late TextEditingController _inputController;
  Timer? _timer;

  @override
  void initState() {
    super.initState();
    _action = widget.action;
    _duration = widget.duration;
    _btnClearController = StreamController<bool>();
    _inputController = TextEditingController();
  }

  @override
  void dispose() {
    _btnClearController.close();
    _inputController.dispose();
    _timer?.cancel();
    super.dispose();
  }

  runDebouncer(String text) {
    _timer?.cancel();
    if (text.isNotEmpty) {
      _btnClearController.add(true);
      _timer = Timer(_duration, () => _action(text));
    } else {
      _btnClearController.add(false);
      if (widget.onTextfieldEmpty != null) {
        widget.onTextfieldEmpty!();
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: widget.direction,
      child: Container(
        height: widget.height,
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            widget.leadingWidget,
            const SizedBox(width: 5),
            Expanded(
              child: TextFormField(
                controller: _inputController,
                onChanged: (value) => runDebouncer(value),
                decoration: widget.inputDecoration,
                style: widget.textFieldStyle,
              ),
            ),
            StreamBuilder<bool>(
                stream: _btnClearController.stream,
                builder: (context, snapshot) {
                  return snapshot.data == true
                      ? GestureDetector(
                          onTap: () {
                            _inputController.clear();
                            _btnClearController.add(false);
                            if (widget.onTextfieldEmpty != null) {
                              widget.onTextfieldEmpty!();
                            }
                          },
                          child: widget.clearButtonIcon)
                      : const SizedBox.shrink();
                }),
          ],
        ),
        decoration: widget.textFieldDecoration,
        padding: widget.padding,
        margin: widget.margin,
      ),
    );
  }
}
